r2899 - in jhalfs/branches/experimental: CLFS CLFS2 HLFS LFS
manuel at linuxfromscratch.org
manuel at linuxfromscratch.org
Sun Aug 6 04:59:41 MDT 2006
Author: manuel
Date: 2006-08-06 04:59:36 -0600 (Sun, 06 Aug 2006)
New Revision: 2899
Modified:
jhalfs/branches/experimental/CLFS/master.sh
jhalfs/branches/experimental/CLFS2/master.sh
jhalfs/branches/experimental/HLFS/master.sh
jhalfs/branches/experimental/LFS/master.sh
Log:
Renamed user-{c,h}lfs-exist to luser-exist.
Renamed restore-{c,h}lfs-env to restore-luser-env.
Modified: jhalfs/branches/experimental/CLFS/master.sh
===================================================================
--- jhalfs/branches/experimental/CLFS/master.sh 2006-08-06 10:21:30 UTC (rev 2898)
+++ jhalfs/branches/experimental/CLFS/master.sh 2006-08-06 10:59:36 UTC (rev 2899)
@@ -45,7 +45,7 @@
groupadd \$(LGROUP); \\
useradd -s /bin/bash -g \$(LGROUP) -m -k /dev/null \$(LUSER); \\
else \\
- touch user-clfs-exist; \\
+ touch luser-exist; \\
fi;
@chown \$(LUSER) \$(MOUNT_PT) && \\
chown \$(LUSER) \$(MOUNT_PT)/tools && \\
@@ -1053,7 +1053,7 @@
chapter4: chapter3 $temptools
-chapter5: chapter4 $chroottools $testsuitetools
+chapter5: chapter4 $chroottools restore-luser-env $testsuitetools
chapter6: chapter5 $basicsystem
@@ -1070,7 +1070,7 @@
@echo "This feature does not exist for the CLFS makefile. (yet)"
clean-chapter2:
- -if [ ! -f user-clfs-exist ]; then \\
+ -if [ ! -f luser-exist ]; then \\
userdel \$(LUSER); \\
rm -rf /home/\$(LUSER); \\
fi;
@@ -1078,12 +1078,12 @@
rm -f /tools
rm -rf \$(MOUNT_PT)/cross-tools
rm -f /cross-tools
- rm -f envars user-clfs-exist
+ rm -f envars luser-exist
rm -f 02* logs/02*.log
clean-chapter3:
rm -rf \$(MOUNT_PT)/tools/*
- rm -f $cross_tools restore-clfs-env sources-dir
+ rm -f $cross_tools sources-dir
cd logs && rm -f $cross_tools && cd ..
clean-chapter4:
@@ -1097,7 +1097,7 @@
cd logs && rm -f $temptools && cd ..
-restore-clfs-env:
+restore-luser-env:
@\$(call echo_message, Building)
@if [ -f /home/\$(LUSER)/.bashrc.XXX ]; then \\
mv -f /home/\$(LUSER)/.bashrc.XXX /home/\$(LUSER)/.bashrc; \\
@@ -1116,7 +1116,7 @@
@-umount \$(MOUNT_PT)/dev
@-umount \$(MOUNT_PT)/sys
@-umount \$(MOUNT_PT)/proc
- @-if [ ! -f user-clfs-exist ]; then \\
+ @-if [ ! -f luser-exist ]; then \\
userdel \$(LUSER); \\
rm -rf /home/\$(LUSER); \\
fi;
@@ -1136,7 +1136,7 @@
$cross_tools\
$temptools \
$chroottools \
- $boottools
+ $boottools restore-luser-env
@\$(call echo_boot_finished,$VERSION)
makesys: $testsuitetools $basicsystem $bootscripttools $bootabletools
@@ -1152,7 +1152,7 @@
@echo "This feature does not exist for the CLFS makefile. (yet)"
clean-jhalfs:
- -if [ ! -f user-clfs-exist ]; then \\
+ -if [ ! -f luser-exist ]; then \\
userdel \$(LUSER); \\
rm -rf /home/\$(LUSER); \\
fi;
@@ -1160,13 +1160,13 @@
rm -f /tools
rm -rf \$(MOUNT_PT)/cross-tools
rm -f /cross-tools
- rm -f envars user-clfs-exist
+ rm -f envars luser-exist
rm -f 02* logs/02*.log
clean-makeboot:
rm -rf /tools/*
rm -f $cross_tools && rm -f $temptools && rm -f $chroottools && rm -f $boottools
- rm -f restore-clfs-env sources-dir
+ rm -f restore-luser-env sources-dir
cd logs && rm -f $cross_tools && rm -f $temptools && rm -f $chroottools && rm -f $boottools && cd ..
clean-makesys:
@@ -1182,7 +1182,7 @@
cd logs && rm -f $basicsystem && rm -f $bootscripttools && rm -f $bootabletools && cd ..
-restore-clfs-env:
+restore-luser-env:
@\$(call echo_message, Building)
@if [ -f /home/\$(LUSER)/.bashrc.XXX ]; then \\
mv -fv /home/\$(LUSER)/.bashrc.XXX /home/\$(LUSER)/.bashrc; \\
Modified: jhalfs/branches/experimental/CLFS2/master.sh
===================================================================
--- jhalfs/branches/experimental/CLFS2/master.sh 2006-08-06 10:21:30 UTC (rev 2898)
+++ jhalfs/branches/experimental/CLFS2/master.sh 2006-08-06 10:59:36 UTC (rev 2899)
@@ -36,7 +36,7 @@
groupadd \$(LGROUP); \\
useradd -s /bin/bash -g \$(LGROUP) -m -k /dev/null \$(LUSER); \\
else \\
- touch user-clfs-exist; \\
+ touch luser-exist; \\
fi;
@chown \$(LUSER) \$(MOUNT_PT) && \\
chown \$(LUSER) \$(MOUNT_PT)/tools && \\
@@ -438,7 +438,7 @@
# as a dependency.
(
cat << EOF
-all: chapter2 chapter3 chapter4 chapter5 chapter6 do-housekeeping
+all: chapter2 chapter3 chapter4 chapter5 chapter6 restore-luser-env do-housekeeping
@\$(call echo_finished,$VERSION)
chapter2: 023-creatingtoolsdir 025-addinguser 026-settingenvironment 027-create-directories 028-creating-sysfile
@@ -459,7 +459,7 @@
restart:
@echo "This feature does not exist for the CLFS makefile. (yet)"
-restore-clfs-env:
+restore-luser-env:
@\$(call echo_message, Building)
@if [ -f /home/\$(LUSER)/.bashrc.XXX ]; then \\
mv -f /home/\$(LUSER)/.bashrc.XXX /home/\$(LUSER)/.bashrc; \\
@@ -473,7 +473,7 @@
echo --------------------------------------------------------------------------------\$(WHITE)
do-housekeeping:
- @-if [ ! -f user-clfs-exist ]; then \\
+ @-if [ ! -f luser-exist ]; then \\
userdel \$(LUSER); \\
rm -rf /home/\$(LUSER); \\
fi;
Modified: jhalfs/branches/experimental/HLFS/master.sh
===================================================================
--- jhalfs/branches/experimental/HLFS/master.sh 2006-08-06 10:21:30 UTC (rev 2898)
+++ jhalfs/branches/experimental/HLFS/master.sh 2006-08-06 10:59:36 UTC (rev 2899)
@@ -84,7 +84,7 @@
TARGET="pc-linux-gnu"; LOADER="ld-linux.so.2"
fi
# If /home/hlfs is already present in the host, we asume that the
# hlfs user and group are also presents in the host, and a backup
# of their bash init files is made.
(
@@ -108,7 +108,7 @@
groupadd \$(LGROUP); \\
useradd -s /bin/bash -g \$(LGROUP) -m -k /dev/null \$(LUSER); \\
else \\
- touch user-hlfs-exist; \\
+ touch luser-exist; \\
fi;
@chown \$(LUSER) \$(MOUNT_PT)/tools && \\
chown \$(LUSER) \$(MOUNT_PT)/sources && \\
@@ -524,7 +524,7 @@
chapter3: 020-creatingtoolsdir 021-addinguser 022-settingenvironment
-chapter5: chapter3 $chapter5 restore-hlfs-env
+chapter5: chapter3 $chapter5 restore-luser-env
chapter6: chapter5 $chapter6
@@ -538,18 +538,18 @@
restart: restart_code all
clean-chapter3:
- -if [ ! -f user-hlfs-exist ]; then \\
+ -if [ ! -f luser-exist ]; then \\
userdel \$(LUSER); \\
rm -rf /home/\$(LUSER); \\
fi;
rm -rf \$(MOUNT_PT)/tools
rm -f /tools
- rm -f envars user-hlfs-exist
+ rm -f envars luser-exist
rm -f 02* logs/02*.log
clean-chapter5:
rm -rf \$(MOUNT_PT)/tools/*
- rm -f $chapter5 restore-hlfs-env sources-dir
+ rm -f $chapter5 restore-luser-env sources-dir
cd logs && rm -f $chapter5 && cd ..
clean-chapter6:
@@ -566,7 +566,7 @@
rm -f $chapter7
cd logs && rm -f $chapter7 && cd ..
-restore-hlfs-env:
+restore-luser-env:
@\$(call echo_message, Building)
@if [ -f /home/\$(LUSER)/.bashrc.XXX ]; then \\
mv -f /home/\$(LUSER)/.bashrc.XXX /home/\$(LUSER)/.bashrc; \\
@@ -585,7 +585,7 @@
@-umount \$(MOUNT_PT)/dev
@-umount \$(MOUNT_PT)/sys
@-umount \$(MOUNT_PT)/proc
- @-if [ ! -f user-hlfs-exist ]; then \\
+ @-if [ ! -f luser-exist ]; then \\
userdel \$(LUSER); \\
rm -rf /home/\$(LUSER); \\
fi;
@@ -84,7 +84,7 @@
TARGET="pc-linux-gnu"; LOADER="ld-linux.so.2"
fi
- # If /home/hlfs is already present in the host, we asume that the
+ # If /home/$LUSER is already present in the host, we asume that the
# hlfs user and group are also presents in the host, and a backup
# of their bash init files is made.
Modified: jhalfs/branches/experimental/LFS/master.sh
===================================================================
--- jhalfs/branches/experimental/LFS/master.sh 2006-08-06 10:21:30 UTC (rev 2898)
+++ jhalfs/branches/experimental/LFS/master.sh 2006-08-06 10:59:36 UTC (rev 2899)
@@ -13,7 +13,7 @@
#----------------------------#
echo "${tab_}${GREEN}Processing... ${L_arrow}Chapter4${R_arrow}"
# If /home/lfs is already present in the host, we asume that the
# lfs user and group are also presents in the host, and a backup
# of their bash init files is made.
(
@@ -33,7 +33,7 @@
groupadd \$(LGROUP); \\
useradd -s /bin/bash -g \$(LGROUP) -m -k /dev/null \$(LUSER); \\
else \\
- touch user-lfs-exist; \\
+ touch luser-exist; \\
fi;
@chown \$(LUSER) \$(MOUNT_PT)/tools && \\
chmod a+wt \$(MOUNT_PT)/sources && \\
@@ -402,7 +402,7 @@
chapter4: 020-creatingtoolsdir 021-addinguser 022-settingenvironment
-chapter5: chapter4 $chapter5 restore-lfs-env
+chapter5: chapter4 $chapter5 restore-luser-env
chapter6: chapter5 $chapter6
@@ -416,18 +416,18 @@
restart: restart_code all
clean-chapter4:
- -if [ ! -f user-lfs-exist ]; then \\
+ -if [ ! -f luser-exist ]; then \\
userdel \$(LUSER); \\
rm -rf /home/\$(LUSER); \\
fi;
rm -rf \$(MOUNT_PT)/tools
rm -f /tools
- rm -f envars user-lfs-exist
+ rm -f envars luser-exist
rm -f 02* logs/02*.log
clean-chapter5:
rm -rf \$(MOUNT_PT)/tools/*
- rm -f $chapter5 restore-lfs-env sources-dir
+ rm -f $chapter5 restore-luser-env sources-dir
cd logs && rm -f $chapter5 && cd ..
clean-chapter6:
@@ -444,7 +444,7 @@
rm -f $chapter789
cd logs && rm -f $chapter789 && cd ..
-restore-lfs-env:
+restore-luser-env:
@\$(call echo_message, Building)
@if [ -f /home/\$(LUSER)/.bashrc.XXX ]; then \\
mv -f /home/\$(LUSER)/.bashrc.XXX /home/\$(LUSER)/.bashrc; \\
@@ -463,7 +463,7 @@
@-umount \$(MOUNT_PT)/dev/shm
@-umount \$(MOUNT_PT)/dev/pts
@-umount \$(MOUNT_PT)/dev
- @-if [ ! -f user-lfs-exist ]; then \\
+ @-if [ ! -f luser-exist ]; then \\
userdel \$(LUSER); \\
rm -rf /home/\$(LUSER); \\
fi;
@@ -13,7 +13,7 @@
#----------------------------#
echo "${tab_}${GREEN}Processing... ${L_arrow}Chapter4${R_arrow}"
-# If /home/lfs is already present in the host, we asume that the
+# If /home/$LUSER is already present in the host, we asume that the
# lfs user and group are also presents in the host, and a backup
# of their bash init files is made.
More information about the alfs-log
mailing list